@@ -18,8 +18,7 @@ class MultiColumns(CMSPlugin):
     A plugin that has sub Column classes
     """
     def __unicode__(self):
-        # TODO: prevent the extra db-hit
-        return u"%s columns" % self.cmsplugin_set.all().count()
+        return _(u"%s columns") % self.cmsplugin_set.all().count()
 
 
 class Column(CMSPlugin):
